/*
  This file is part of TALER
  (C) 2014, 2015, 2016 INRIA

  TALER is free software; you can redistribute it and/or modify it under the
  terms of the GNU Affero General Public License as published by the Free Software
  Foundation; either version 3, or (at your option) any later version.

  TALER is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
  A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with
  TALER; see the file COPYING.  If not, If not, see <http://www.gnu.org/licenses/>
*/
/**
 * @file backend/taler-merchant-httpd_track.c
 * @brief implement API for tracking deposits and wire transfers
 * @author Marcello Stanisci
 */
#include "platform.h"
#include <jansson.h>
#include <taler/taler_signatures.h>
#include <taler/taler_json_lib.h>
#include "taler-merchant-httpd.h"
#include "taler-merchant-httpd_mhd.h"
#include "taler-merchant-httpd_parsing.h"
#include "taler-merchant-httpd_auditors.h"
#include "taler-merchant-httpd_exchanges.h"
#include "taler-merchant-httpd_responses.h"


extern char *TMH_merchant_currency_string;


/**
 * Manages a /track/deposit call, thus it calls the /wire/deposit
 * offered by the exchange in order to return the set of deposits
 * (of coins) associated with a given wire transfer
 *
 * @param rh context of the handler
 * @param connection the MHD connection to handle
 * @param[in,out] connection_cls the connection's closure (can be updated)
 * @param upload_data upload data
 * @param[in,out] upload_data_size number of bytes (left) in @a upload_data
 * @return MHD result code
 */
int
MH_handler_track_deposit (struct TMH_RequestHandler *rh,
                          struct MHD_Connection *connection,
                          void **connection_cls,
                          const char *upload_data,
                          size_t *upload_data_size)
{
  static struct TMH_RequestHandler pong =
    {
      "", NULL, "text/html",
      "/track/deposit served\n", 0,
      &TMH_MHD_handler_static_response, MHD_HTTP_OK
    };

  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "serving /track/deposit\n");
  return TMH_MHD_handler_static_response (&pong,
                                          connection,
                                          connection_cls,
                                          upload_data,
                                          upload_data_size);
}

/* end of taler-merchant-httpd_contract.c */
